@@ -223,6 +223,167 @@ class Solution_1857(Solution):
 
     main = largestPathValue
 
+class Solution_1900(Solution):
+    def __init__(self):
+        super().__init__('kcsquared', 1900, 'Hard')
+
+    main = None
+
+    def earliestAndLatest(self, n, a, b):
+        '''
+        Author: @kcsquared (I couldn't find any other clean & concise solutions), trickey problem.
+        Link: https://leetcode.com/problems/the-earliest-and-latest-rounds-where-players-compete/?envType=daily-question&envId=2025-07-12
+        Original Solution Link: https://leetcode.com/problems/the-earliest-and-latest-rounds-where-players-compete/solutions/1272828/10-lines-0ms-bit-counting-solution-o-1-time-o-1-space
+
+        :type n: int
+        :type firstPlayer: int
+        :type secondPlayer: int
+        :rtype: List[int]
+        '''
+
+        def ceiling_of_log2(x):
+            offset = 1 if (x & (x - 1)) != 0 else 0
+            x |= (x >> 1)
+            x |= (x >> 2)
+            x |= (x >> 4)
+            x |= (x >> 8)
+            x |= (x >> 16)
+            return popcount(x) - 1 + offset
+
+        def popcount(x):
+            x = x - ((x >> 1) & 0x55555555)
+            x = (x & 0x33333333) + ((x >> 2) & 0x33333333)
+            return (((x + (x >> 4) & 0xF0F0F0F) * 0x1010101) & 0xffffffff) >> 24
+
+        def count_trailing_zeroes(x):
+            if x & 0x1:
+                return 0
+
+            c = 1
+
+            if (x & 0xffff) == 0:
+                x >>= 16
+                c += 16
+
+            if (x & 0xff) == 0:
+                x >>= 8
+                c += 8
+
+            if (x & 0xf) == 0:
+                x >>= 4
+                c += 4
+
+            if (x & 0x3) == 0:
+                x >>= 2
+                c += 2
+
+            return c - (x & 0x1)
+
+        if a + b == n + 1:
+            return [1, 1]
+
+        if a + b >= n + 1:
+            a, b = n + 1 - b, n + 1 - a
+
+        first_plus_second = a + b
+
+        if a + 1 != b and first_plus_second >= (n + 1) // 2 + 1:
+            if first_plus_second == n:
+                if n % 4 == 2 and a + 2 == b:
+                    ans_earliest = 3 + count_trailing_zeroes(n // 4)
+
+                else:
+                    ans_earliest = 3 - (a % 2)
+            else:
+                ans_earliest = 2
+
+        else:
+            ans_earliest = 1 + ceiling_of_log2((n + first_plus_second - 2) // (first_plus_second - 1))
+
+            if a + 1 == b:
+                ans_earliest += count_trailing_zeroes(((n + (1 << (ans_earliest - 1)) - 1) >> (ans_earliest - 1)) - 1)
+
+        ans_latest = min(ceiling_of_log2(n), n + 1 - b)
+
+        return [ans_earliest, ans_latest]
+
+    main = earliestAndLatest
+
+class Solution_1948(Solution):
+    def __init__(self):
+        super().__init__('ChatGPT', 1948, 'Hard')
+
+    main = None
+
+    def deleteDuplicateFolder(self, paths):
+        '''
+        Author: ChatGPT
+        Link: https://leetcode.com/problems/delete-duplicate-folders-in-system/?envType=daily-question&envId=2025-07-20
+
+        :type paths: List[List[str]]
+        :rtype: List[List[str]]
+        '''
+
+        from collections import defaultdict
+
+        class Node:
+            def __init__(self):
+                self.children = {}
+                self.deletion_flag = False
+                self.serial = ''
+
+        root = Node()
+
+        # Step 1: Build the folder tree (trie)
+        for path in sorted(paths):
+            cur = root
+            for folder in path:
+                if folder not in cur.children:
+                    cur.children[folder] = Node()
+                cur = cur.children[folder]
+
+        # Step 2: Serialize each subtree to find duplicates
+        counter = defaultdict(int)
+
+        def dfs_serialize(node):
+            if not node.children:
+                return ''
+            parts = []
+            for name in sorted(node.children):
+                child_serial = dfs_serialize(node.children[name])
+                parts.append(name + '(' + child_serial + ')')
+            node.serial = ''.join(parts)
+            counter[node.serial] += 1
+            return node.serial
+
+        dfs_serialize(root)
+
+        # Step 3: Mark duplicates for deletion
+        def dfs_mark(node):
+            if node.serial and counter[node.serial] > 1:
+                node.deletion_flag = True
+            for child in node.children.values():
+                dfs_mark(child)
+
+        dfs_mark(root)
+
+        # Step 4: Collect paths excluding deleted nodes
+        result = []
+
+        def dfs_collect(node, path):
+            for name, child in node.children.items():
+                if child.deletion_flag:
+                    continue
+
+                result.append(path + [name])
+                dfs_collect(child, path + [name])
+
+        dfs_collect(root, [])
+
+        return result
+
+    main = deleteDuplicateFolder
+
 class Solution_2014(Solution):
     def __init__(self):
         super().__init__('Kevin Zhu', 2014, 'Hard')
@@ -414,6 +575,195 @@ class Solution_2081(Solution):
 
     main = kMirror
 
+class Solution_2163(Solution):
+    def __init__(self):
+        super().__init__('Kevin Zhu / ChatGPT', 2163, 'Hard')
+
+    main = None
+
+    def minimumDifference(self, nums):
+        '''
+        Author: Kevin Zhu (ChatGPT for double heap idea)
+        Link: https://leetcode.com/problems/minimum-difference-in-sums-after-removal-of-elements/?envType=daily-question&envId=2025-07-18
+
+        :type nums: List[int]
+        :rtype: int
+        '''
+
+        import heapq
+
+        n = len(nums) // 3 # should just be / 3
+
+        # prefix sum of smallest n elements in first 2n
+        max_heap = []
+        for i in range(n):
+            heapq.heappush(max_heap, -nums[i])  # use negative values for smallest
+
+        prefix = [0] * (n + 1)
+        prefix[0] = -sum(max_heap) # since negative
+
+        for i in range(n):
+            new_val = nums[i + n]
+            # double negative: since it is already negative, add it to the value to remove
+            prefix[i + 1] = prefix[i] + heapq.heappushpop(max_heap, -new_val) + new_val
+
+        # suffix sum of largest n elements in last 2n
+        min_heap = []
+        for i in reversed(range(2 * n, 3 * n)):
+            heapq.heappush(min_heap, nums[i])
+
+        suffix = sum(min_heap)
+
+        # minimum difference between the nth prefix and (nth) suffix
+        result = prefix[n] - suffix
+
+        for i in reversed(range(n)):
+            new_val = nums[i + n]
+            suffix += new_val - heapq.heappushpop(min_heap, new_val)
+            result = min(result, prefix[i] - suffix)
+
+        return result
+
+    main = minimumDifference
+
+class Solution_2163(Solution):
+    def __init__(self):
+        super().__init__('ChatGPT', 2322, 'Hard')
+
+    main = None
+
+    def minimumScore(self, nums, edges):
+        '''
+        Author: ChatGPT
+        Link: https://leetcode.com/problems/minimum-score-after-removals-on-a-tree/?envType=daily-question&envId=2025-07-24
+
+        :type nums: List[int]
+        :type edges: List[List[int]]
+        :rtype: int
+        '''
+
+        from collections import defaultdict
+
+        '''
+        My understanding of XOR:
+        A XOR B, eg. 3 XOR 6, into binary -->
+        0011
+        0110
+        ----
+        0101
+        A 1 bit flips the other...
+        but this is implemented in Python by the ^ operator.
+        '''
+
+        n = len(nums)
+        if n <= 2:
+            return 0
+
+        graph = defaultdict(list)
+        for u, v in edges:
+            graph[u].append(v)
+            graph[v].append(u)
+
+        # Step 1: DFS to get subtree XOR and in/out times
+        in_time = [0] * n
+        out_time = [0] * n
+        xor = [0] * n
+        time = [0]
+
+        def dfs(u, parent):
+            in_time[u] = time[0]
+            time[0] += 1
+            xor[u] = nums[u]
+
+            for v in graph[u]:
+                if v != parent:
+                    dfs(v, u)
+                    xor[u] ^= xor[v]
+
+            out_time[u] = time[0]
+            time[0] += 1
+
+        dfs(0, -1)
+
+        total_xor = xor[0]
+        result = float('inf')
+
+        def is_ancestor(u, v):
+            return in_time[u] < in_time[v] and out_time[v] < out_time[u]
+
+        # Step 2: Iterate through all pairs of nodes (potential second cuts)
+        for i in range(1, n):
+            for j in range(i + 1, n):
+                a, b, c = 0, 0, 0
+
+                # Case 1: i is an ancestor of j
+                if is_ancestor(i, j):
+                    a = xor[j]
+                    b = xor[i] ^ xor[j]
+                    c = total_xor ^ xor[i]
+
+                # Case 2: j is an ancestor of i
+                elif is_ancestor(j, i):
+                    a = xor[i]
+                    b = xor[j] ^ xor[i]
+                    c = total_xor ^ xor[j]
+
+                # Case 3: Neither is an ancestor of the other
+                else:
+                    a = xor[i]
+                    b = xor[j]
+                    c = total_xor ^ xor[i] ^ xor[j]
+
+                result = min(result, max(a, b, c) - min(a, b, c))
+
+        return result
+
+    main = minimumScore
+
+class Solution_2402(Solution):
+    def __init__(self):
+        super().__init__('Kevin Zhu', 2402, 'Hard')
+
+    main = None
+
+    def mostBooked(self, n, meetings):
+        '''
+        Author: Kevin Zhu
+        Link: https://leetcode.com/problems/meeting-rooms-iii/?envType=daily-question&envId=2025-07-11
+
+        :type n: int
+        :type meetings: List[List[int]]
+        :rtype: int
+        '''
+
+        import heapq
+
+        meetings.sort()
+
+        used_rooms = [] # end time, room #
+        empty_rooms = list(range(n)) # empty room numbers
+        heapq.heapify(empty_rooms)
+
+        count = [0] * n # necessary tracker
+
+        for start_time, end_time in meetings:
+            while used_rooms and used_rooms[0][0] <= start_time:
+                heapq.heappush(empty_rooms, heapq.heappop(used_rooms)[1]) # free any meetings that have ended and add to empty_rooms
+
+            if empty_rooms: # Case 1: room is free
+                room_number = heapq.heappop(empty_rooms)
+
+            else: # Case 2: wait until room is free
+                earliest, room_number = heapq.heappop(used_rooms) # get earliest end room
+                end_time = earliest + (end_time - start_time) # shift the end time of this meeting, keeping the same duration
+
+            count[room_number] += 1
+            heapq.heappush(used_rooms, (end_time, room_number)) # mark this room as used
+
+        return count.index(max(count))
+
+    main = mostBooked
+
 class Solution_3307(Solution):
     def __init__(self):
         super().__init__('Kevin Zhu', 3307, 'Hard')
@@ -819,4 +1169,5 @@ class Solution_3445(Solution):
         # So `max_overall_diff` should not remain -inf.
         return max_overall_diff
 
-    main = maxDifference
\ No newline at end of file
+    main = maxDifference
+
