@@ -213,6 +213,34 @@ class Solution_1061_B(Solution):
 
     main = smallestEquivalentString
 
+class Solution_1233(Solution):
+    def __init__(self):
+        super().__init__('Kevin Zhu', 1233, 'Medium')
+
+    main = None
+
+    def removeSubfolders(self, folder):
+        '''
+        Author: Kevin Zhu
+        Link: https://leetcode.com/problems/remove-sub-folders-from-the-filesystem/?envType=daily-question&envId=2025-07-19
+
+        :type folder: List[str]
+        :rtype: List[str]
+        '''
+
+        folder.sort()
+        current_root = folder[0]
+        result = [current_root]
+
+        for f in folder[1:]:
+            if not f.startswith(current_root + '/'):
+                current_root = f
+                result.append(f)
+
+        return result
+
+    main = removeSubfolders
+
 class Solution_1353(Solution):
     def __init__(self):
         super().__init__('Kevin Zhu', 1353, 'Medium')
@@ -350,6 +378,93 @@ class Solution_1498(Solution):
 
     main = numSubseq
 
+class Solution_1695(Solution):
+    def __init__(self):
+        super().__init__('Kevin Zhu', 1695, 'Medium')
+
+    main = None
+
+    def maximumUniqueSubarray(self, nums):
+        '''
+        Author: Kevin Zhu
+        Link: https://leetcode.com/problems/maximum-erasure-value/?envType=daily-question&envId=2025-07-22
+
+        :type nums: List[int]
+        :rtype: int
+        '''
+
+        visited = set()
+        answer = 0
+        current_sum = 0
+        left = 0
+
+        for right in range(len(nums)):
+            while nums[right] in visited: # shrink the array until the current isn't in the visited
+                visited.remove(nums[left])
+                current_sum -= nums[left] # 'shrink'
+                left += 1 # continue shrinking
+
+            visited.add(nums[right]) # expand
+            current_sum += nums[right]
+            answer = max(answer, current_sum)
+
+        return answer
+
+    main = maximumUniqueSubarray
+
+class Solution_1717(Solution):
+    def __init__(self):
+        super().__init__('Kevin Zhu', 1717, 'Medium')
+
+    main = None
+
+    def maximumGain(self, s, x, y):
+        """
+        Author: Kevin Zhu
+        Link: https://leetcode.com/problems/maximum-score-from-removing-substrings/?envType=daily-question&envId=2025-07-23
+
+        :type s: str
+        :type x: int
+        :type y: int
+        :rtype: int
+        """
+
+        def remove_pair(_s, key, score):
+            stack = []
+            total = 0
+
+            first, second = key
+
+            for c in _s:
+                '''
+                this stack works because it will always process the moment there is a pair
+                even if it is like bbbbbaaaaa, the stack will have all the b's and then
+                for each a, it will eventually match up
+                if it wasw like bbcaaa, they will never be able to meet (so it won't be a substring)
+                same thing for ab, which must be done after ba (if it is worth less) to maximize rewards
+                '''
+                
+                if stack and stack[-1] == first and c == second:
+                    stack.pop()
+                    total += score
+
+                else:
+                    stack.append(c)
+
+            return ''.join(stack), total
+
+        if x > y: # get the optimal since order matters
+            s, score_x = remove_pair(s, 'ab', x)
+            s, score_y = remove_pair(s, 'ba', y)
+
+        else:
+            s, score_x = remove_pair(s, 'ba', y)
+            s, score_y = remove_pair(s, 'ab', x)
+
+        return score_x + score_y
+
+    main = maximumGain
+
 class Solution_1865(Solution):
     def __init__(self):
         super().__init__('Kevin Zhu', 1865, 'Medium')
@@ -622,6 +737,41 @@ class Solution_2359(Solution):
 
     main = closestMeetingNode
 
+class Solution_2410(Solution):
+    def __init__(self):
+        super().__init__('Kevin Zhu', 2410, 'Medium')
+
+    main = None
+
+    def matchPlayersAndTrainers(self, players, trainers):
+        '''
+        Author: Kevin Zhu
+        Link: https://leetcode.com/problems/maximum-matching-of-players-with-trainers/?envType=daily-question&envId=2025-07-13
+
+        :type players: List[int]
+        :type trainers: List[int]
+        :rtype: int
+        '''
+
+        players.sort(reverse = True)
+        trainers.sort(reverse = True)
+
+        matches = 0
+        t = 0
+        max_t = len(trainers)
+
+        for player in players:
+            if t == max_t:
+                break
+
+            if player <= trainers[t]: # greedy
+                matches += 1
+                t += 1
+
+        return matches
+
+    main = matchPlayersAndTrainers
+
 class Solution_2434(Solution):
     '''
     Plan:
@@ -890,6 +1040,205 @@ class Solution_3170(Solution):
 
     main = clearStars
 
+class Solution_3201(Solution):
+    def __init__(self):
+        super().__init__('Kevin Zhu', 3201, 'Medium')
+
+    main = None
+
+    def maximumLength(self, nums):
+        '''
+        Author: Kevin Zhu
+        Link: https://leetcode.com/problems/find-the-maximum-length-of-valid-subsequence-i/?envType=daily-question&envId=2025-07-16
+
+        :type nums: List[int]
+        :rtype: int
+        '''
+
+        '''
+        a run of odd + odd = even,
+        a run of even + even = even,
+        a run of odd + even = odd.
+        We can find the longest of these runs.
+        '''
+
+        odds = 0
+        evens = 0
+        alternates = 1 # no matter what, it started to alternate
+        previous = nums[0] % 2
+
+        if previous:
+            odds += 1
+
+        else:
+            evens += 1
+
+        for num in nums[1:]:
+            num = num % 2
+
+            if num:
+                odds += 1
+
+            else:
+                evens += 1
+
+            if num != previous:
+                alternates += 1
+                previous = num
+
+        return max(odds, evens, alternates)
+
+    main = maximumLength
+
+class Solution_3202(Solution):
+    def __init__(self):
+        super().__init__('Kevin Zhu', 3202, 'Medium')
+
+    main = None
+
+    def maximumLength(self, nums, k):
+        '''
+        Author: Kevin Zhu
+        Link: https://leetcode.com/problems/find-the-maximum-length-of-valid-subsequence-ii/?envType=daily-question&envId=2025-07-17
+
+        :type nums: List[int]
+        :type k: int
+        :rtype: int
+        '''
+
+        '''
+        k = 3
+        0, 1, 3, 4, 6, 7 # 1
+
+        0, 3, 6, 9 # 0
+
+        0, 2, 3, 5, 6, 8 # 2
+
+        1, 2, 4, 5 # 0
+
+        k = 4
+        0, 1, 4, 5
+
+        0, 4, 8, 12
+        '''
+
+        mod_results = []
+
+        for mod_target in range(k): # every possible modulus result
+            dp = [0] * k # dp[j] = max len subsequence such that x % k == j and two consecutive elements in the subsequence % k = mod_target
+
+            for x in nums:
+                dp[x % k] = dp[(mod_target - x) % k] + 1
+                # finding the 'pair' that this would go with, then updating the max length for a future pairing
+
+                '''
+                Example:
+                k = 3, mod_target = 2
+                0, 5, 7, 8, 2, 1
+                At x == 2: the pair would be x == 0, at x == 1: the pair would be x == 7 (7 % 3 == 1, 1 + 1 == 2)
+                '''
+
+            mod_results.append(max(dp))
+
+        return max(mod_results)
+
+    main = maximumLength
+
+class Solution_3439(Solution):
+    def __init__(self):
+        super().__init__('Kevin Zhu', 3439, 'Medium')
+
+    main = None
+
+    def maxFreeTime(self, eventTime, k, startTime, endTime):
+        '''
+        Author: Kevin Zhu
+        Link: https://leetcode.com/problems/reschedule-meetings-for-maximum-free-time-i/?envType=daily-question&envId=2025-07-09
+
+        :type eventTime: int
+        :type k: int
+        :type startTime: List[int]
+        :type endTime: List[int]
+        :rtype: int
+        '''
+
+        '''
+        Important: Research indicates that problem 3439 is incorrect.
+        The actual description should go along the lines of...
+        'What is the maximum length of one continuous free time interval you can create by removing exactly k consecutive meetings?'
+        '''
+
+        n = len(startTime)
+
+        free_time = [0] * (n + 1)
+        free_time[0] = startTime[0]
+
+        for i in range(1, n):
+            free_time[i] = startTime[i] - endTime[i - 1] # ignore the meeting
+
+        free_time[n] = eventTime - endTime[n - 1] # free time in blocks if meetings were removed
+
+        current = sum(free_time[:k + 1]) # if you remove all meetings, including the gap after the last meeting removed
+        answer = current
+
+        for i in range(k + 1, n + 1):
+            current += free_time[i] - free_time[i - (k + 1)] # always change the current, simulate keeping the first and removing the last
+
+            if current > answer: # only update if better
+                answer = current
+
+        return answer
+
+    main = maxFreeTime
+
+class Solution_3440(Solution):
+    def __init__(self):
+        super().__init__('Kevin Zhu', 3440, 'Medium')
+
+    main = None
+
+    def maxFreeTime(self, eventTime, startTime, endTime):
+        '''
+        Author: Kevin Zhu
+        Link: https://leetcode.com/problems/reschedule-meetings-for-maximum-free-time-ii/?envType=daily-question&envId=2025-07-10
+
+        :type eventTime: int
+        :type startTime: List[int]
+        :type endTime: List[int]
+        :rtype: int
+        '''
+
+        n = len(startTime)
+
+        gaps = [startTime[0]] + [startTime[i] - endTime[i - 1] for i in range(1, n)] + [eventTime - endTime[-1]] # gaps between meetings
+
+        max_left = [0] * (n + 1)
+        max_right = [0] * (n + 1)
+        max_left[0] = gaps[0]
+        max_right[n] = gaps[n]
+
+        for i in range(1, n + 1):
+            max_left[i] = max(max_left[i - 1], gaps[i]) # max gap on the left side
+
+        for i in reversed(range(n)):
+            max_right[i] = max(max_right[i + 1], gaps[i]) # max gap on the right side
+
+        answer = max_left[n]
+
+        for i in range(n):
+            duration = endTime[i] - startTime[i]
+            merged_gap = gaps[i] + gaps[i + 1]
+
+            if duration <= max(max_left[i - 1] if i > 0 else 0, max_right[i + 2] if i + 2 <= n else 0): # can put it outside the current gap
+                answer = max(answer, merged_gap + duration) # moved completely outside the gap
+
+            else:
+                answer = max(answer, merged_gap) # move meeting in gap to combine the two
+
+        return answer
+
+    main = maxFreeTime
+
 class Solution_3443(Solution):
     def __init__(self):
         super().__init__('Kevin Zhu', 3443, 'Medium')
@@ -1039,4 +1388,5 @@ class Solution_3403(Solution):
 
         return best
 
-    main = answerString
\ No newline at end of file
+    main = answerString
+
